package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.CusData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domainCus.CusAcqGoodsMove05;
import com.emato.cus.supervise.domainCus.CusAcqInventoryInfo03;
import com.emato.cus.supervise.domainOms.OmsCusUnitCode;
import com.emato.cus.supervise.mapperOms.OmsCusUnitCodeMapper;
import com.emato.cus.supervise.service.cus.CusAcqInventoryInfoService03;
import com.google.common.collect.Lists;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-02 09:44
 */
@Component
public class AcqInventoryInfoCusData implements CusData {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoCusData.class);

    @Autowired
    private CusAcqInventoryInfoService03 cusAcqInventoryInfoService03;
    @Autowired
    private OmsCusUnitCodeMapper omsCusUnitCodeMapper;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getCode() + "]" + EmtRecordTimeEnum.I_ACQ_INVENTORY_INFO.getName();


    /**
     * 海关抓取库存信息为全量抓取
     * 无则新增，有则更新
     *
     * @param list
     * @return
     */
    @Override
    public int writeCus(List<?> list) {
        logger.info("---------- 货物库存数据::写入本次监控数据开始 --------------------");

        List<CusAcqInventoryInfo03> cusList = ( List<CusAcqInventoryInfo03>)list;

        // 新增库存list
        List<CusAcqInventoryInfo03> insertList = new ArrayList<>();
        // 修改库存list
        List<CusAcqInventoryInfo03> updateList = new ArrayList<>();


        // ------ 查询现有wms_data库存信息表
        List<String> listSku = new ArrayList<>();


        List<String> gUnitNameList = Lists.newArrayList();
        cusList.forEach(
                i -> {
                    gUnitNameList.add(i.getGUnit());

                    // 查询条件
                    listSku.add(i.getSkuNo());
                });
        // 查询已有库存信息表对应sku数据
        List<CusAcqInventoryInfo03> listInveInfo = cusAcqInventoryInfoService03.listCusAcqInventoryInfo(listSku);
        Map<String, String> exitInveInfo = listInveInfo.stream().collect(Collectors.toMap(k->k.getSkuNo(), v->v.getLocalEmsNo()));


        List<OmsCusUnitCode> codeList = omsCusUnitCodeMapper.getOmsCusUnitCodeList(gUnitNameList);
        Map<String,OmsCusUnitCode> omsCusUnitCodeMap = codeList.stream().collect(Collectors.toMap(k->k.getgUnitName(), v->v));

        for (CusAcqInventoryInfo03 info:cusList) {
            OmsCusUnitCode omsProductInfo = omsCusUnitCodeMap.get(info.getGUnit());
            if(omsProductInfo != null) {
                info.setGUnit(omsProductInfo.getgUnitCode());
            }

            if (exitInveInfo.containsKey(info.getSkuNo())) {
                // 存在, 则更新
                updateList.add(info);
            } else {
                // 不存在, 则插入
                insertList.add(info);
            }

        }

        int insertResult = 0;
        int updateResult = 0;

        if (insertList.size() > 0) {
            insertResult = cusAcqInventoryInfoService03.addCusAcqInventoryInfo(insertList);
        }
        if (updateList.size() > 0) {
            updateResult = cusAcqInventoryInfoService03.updateCusAcqInventoryInfo(updateList);
        }


        logger.info("---【" + DATA_TYPE_INFO + "】写入监控数据:{}条, 更新监控数据:{}条", insertResult, updateResult);

        logger.info("---------- 货物库存数据::写入本次监控数据结束 --------------------");
        return insertResult + updateResult;
    }

}
