package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domain.WmsAcqInventoryInfo;
import com.emato.cus.supervise.domainCus.CusAcqInventoryInfo03;
import com.emato.cus.supervise.domainOms.OmsAcqInventoryInfo;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-02 14:43
 */
@Component
public class AcqInventoryInfoDataConversion implements DataConversion {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoDataConversion.class);

    /**
     * 货物库存
     * 将oms，和wms查询处理的数据进行转换
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("货物库存开始转换oms，wms 组装cus数据===========================");

        List<WmsAcqInventoryInfo> wmsList = (List<WmsAcqInventoryInfo>) params.get("wmsList");
        List<OmsAcqInventoryInfo> omsList = (List<OmsAcqInventoryInfo>) params.get("omsList");

        final Map<String,OmsAcqInventoryInfo> omsAcqInventoryInfoMap = omsList.stream().collect(Collectors.toMap(k->k.getMerchSn(),v->v));

        List<OmsProductInfo> productInfoList = (List<OmsProductInfo>) params.get("productInfoList");
        final Map<String,OmsProductInfo> omsProductInfoMap = productInfoList.stream().collect(Collectors.toMap(k->k.getSkuNo(), v->v));

        List<CusAcqInventoryInfo03> cusAcqInventoryInfo03List = Lists.newArrayList();

        for (int i = 0; i < wmsList.size(); i++) {
            try {
                WmsAcqInventoryInfo wmsAcqInventoryInfo = wmsList.get(i);
                OmsAcqInventoryInfo omsAcqInventoryInfo = omsAcqInventoryInfoMap.get(wmsAcqInventoryInfo.getMerchSn());

                OmsProductInfo omsProductInfo = omsProductInfoMap.get(wmsAcqInventoryInfo.getCodeTs());

                String osku = omsProductInfo.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}, 对应的产品备案数据异常", osku);
                    continue;
                }
                logger.debug("当前转换的sku为: {}", omsProductInfo.getSkuNo());

                CusAcqInventoryInfo03 cusAcqInventoryInfo03 = new CusAcqInventoryInfo03();
                cusAcqInventoryInfo03.setGoodsName(wmsAcqInventoryInfo.getGoodsName());
                //wms codeTs（商品编码） = 料件号，sku
//                cusAcqInventoryInfo03.setCodeTs(wmsAcqInventoryInfo.getCodeTs());

                cusAcqInventoryInfo03.setSkuNo(wmsAcqInventoryInfo.getCodeTs());
                cusAcqInventoryInfo03.setGoodsId(wmsAcqInventoryInfo.getCodeTs());

                cusAcqInventoryInfo03.setGUnit(wmsAcqInventoryInfo.getgUnit());
                cusAcqInventoryInfo03.setgQty(wmsAcqInventoryInfo.getgQty());

                //法定单位，法定数量暂时未查询
                cusAcqInventoryInfo03.setLegalUnit(wmsAcqInventoryInfo.getLegalUnit());
                cusAcqInventoryInfo03.setLegalQty(wmsAcqInventoryInfo.getLegalQty());

                cusAcqInventoryInfo03.setGoodsModel(wmsAcqInventoryInfo.getGoodsModel());
                cusAcqInventoryInfo03.setLocalEmsNo(omsAcqInventoryInfo.getLocalEmsNo());

                cusAcqInventoryInfo03.setOwnerCode(omsAcqInventoryInfo.getOwnerCode());
                cusAcqInventoryInfo03.setOwnerName(omsAcqInventoryInfo.getOwnerName());

                cusAcqInventoryInfo03.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqInventoryInfo03.setStoreUscCode(Dict.storeUscCode);
                cusAcqInventoryInfo03.setStoreCustomsCode(Dict.storeCustomsCode);
                cusAcqInventoryInfo03.setStoreCode(Dict.storeCode);
                cusAcqInventoryInfo03.setCreateTime(LocalDateTime.now());
                cusAcqInventoryInfo03.setCreaterSn("1");
                cusAcqInventoryInfo03.setModerSn("1");
                cusAcqInventoryInfo03.setModTime(LocalDateTime.now());
                cusAcqInventoryInfo03.setLegalQty(omsProductInfo.getLegalQyt());
                cusAcqInventoryInfo03.setLegalUnit(omsProductInfo.getLegalUnit());
                cusAcqInventoryInfo03.setGoodsModel(omsProductInfo.getGoodsModel());
                cusAcqInventoryInfo03.setCodeTs(omsProductInfo.getCodeTs());
                cusAcqInventoryInfo03List.add(cusAcqInventoryInfo03);

            }catch (Exception e){
                logger.error("货物库存组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("货物库存组装转换oms，wms 组装cus数据结束===========================");
        return cusAcqInventoryInfo03List;
    }
}
