package com.emato.cus.supervise.biz.acqShelfLoad.up;

import com.emato.cus.supervise.biz.CusData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domainCus.CusAcqGoodsSeat06;
import com.emato.cus.supervise.domainCus.CusAcqShelfLoad04;
import com.emato.cus.supervise.domainOms.OmsCusUnitCode;
import com.emato.cus.supervise.mapperOms.OmsCusUnitCodeMapper;
import com.emato.cus.supervise.service.cus.CusAcqShelfLoadService04;
import com.emato.cus.supervise.util.snow.SnowflakeUtil;
import com.google.common.collect.Lists;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 货物上下架数据 上架 CUS
 * @author Scott Chen
 * @version 1.0
 * 2017-10-31 12:38
 */
@Component
public class AcqShelfLoadUpCusData implements CusData {
    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadUpCusData.class);

    @Autowired
    private CusAcqShelfLoadService04 cusAcqShelfLoadService04;
    @Autowired
    private OmsCusUnitCodeMapper omsCusUnitCodeMapper;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.ACQ_SHELF_LOAD.getCode() + "]" + EmtRecordTimeEnum.ACQ_SHELF_LOAD.getName();


    @Override
    public int writeCus(List<?> list) {
        logger.info("---------- 货物上下架数据::上架::写入本次监控数据开始 --------------------");

        List<CusAcqShelfLoad04> cusList = (List<CusAcqShelfLoad04>) list;

        List<String> gUnitNameList = Lists.newArrayList();
        cusList.forEach(i -> gUnitNameList.add(i.getgUnit()));

        List<OmsCusUnitCode> codeList = omsCusUnitCodeMapper.getOmsCusUnitCodeList(gUnitNameList);
        Map<String,OmsCusUnitCode> omsCusUnitCodeMap = codeList.stream().collect(Collectors.toMap(k->k.getgUnitName(), v->v));

        for (CusAcqShelfLoad04 seat:cusList) {
            OmsCusUnitCode omsProductInfo = omsCusUnitCodeMap.get(seat.getgUnit());
            if(omsProductInfo != null) {
                seat.setgUnit(omsProductInfo.getgUnitCode());
            }

            // #20190521001
            seat.setId(String.valueOf(SnowflakeUtil.getSnowNextId()));
        }

        int result = cusAcqShelfLoadService04.addCusAcqShelfLoad04(cusList);

        logger.info("---【" + DATA_TYPE_INFO + "】写入监控数据:{} 条", result);

        logger.info("---------- 货物上下架数据::上架::写入本次监控数据结束 --------------------");
        return result;
    }
}
